/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: carol@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: ServerExampleActivator.java 2439 2010-02-24 16:21:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.example.server;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.ow2.cmi.base.server.CMIServerExample;
import org.ow2.cmi.base.server.ServerExampleProperty;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;


/**
 * Server example activator.
 *
 * @author eyindanga
 *
 */
public class ServerExampleActivator implements BundleActivator {

	/**
	 * Logger.
	 */
	private static Log logger = LogFactory.getLog(ServerExampleActivator.class);

	/**
	 * The CMI server to start.
	 */
	CMIServerExample server = null;
	/**
	 * Start the bundle.
	 * @param bundleContext the Bundle context.
	 * @throws Exception any.
	 */
	public final void start(final BundleContext bundleContext) throws Exception {
		try {
			final String confFileName = System.getProperty(
					ServerExampleProperty.CONF_FILE_URL_KEY.getPropertyName(),
					String.valueOf(ServerExampleProperty.DEFAULT_CONF_FILE_URL.getPropertyName()));

			final String confDir = System.getProperty(ServerExampleProperty.CONF_DIR_KEY.getPropertyName());
			if (confDir == null) {
				throw new Exception("Configuration directory not set. please set the cmi.conf.dir system property.");
			}
			server = new CMIServerExample(confDir, confFileName);
			server.start();
		} catch (Exception e) {
			logger.error("Unable to start CMI server example", e);
		}

	}

	/**
	 * Stop the bundle.
	 * @param bundleContext the Bundle context.
	 * @throws Exception any.
	 */
	public final void stop(final BundleContext bundleContext) throws Exception {
		server.stop();
	}


}
